@@ -376,10 +376,6 @@ function field_remove_confirm() {
 				loadPageNoHeader('data_input.php?action=edit&header=false&id=<?php print get_request_var('data_input_id');?>');
 			});
 		});
-
-		$('#cancel').unbind().click(function() {
-			$('#cdialog').dialog('close');
-		});
 	});
 	</script>
 	<?php
@@ -747,7 +743,8 @@ function data_edit() {
 	<script type='text/javascript'>
 
 	$(function() {
-		$('body').append("<div id='cdialog'></div>");
+		$('.cdialog').remove();
+		$('#main').append("<div id='cdialog' class='cdialog'></div>");
 
 		$('.delete').unbind().click(function (event) {
 			event.preventDefault();
@@ -756,7 +753,9 @@ function data_edit() {
 			$.get(request)
 				.done(function(data) {
 					$('#cdialog').html(data);
+
 					applySkin();
+
 					$('#cdialog').dialog({
 						title: '<?php print __('Delete Data Input Field');?>',
 						close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
@@ -928,10 +927,36 @@ function data() {
 
 	$display_text = array(
 		'name'         => array('display' => __('Data Input Name'),    'align' => 'left', 'sort' => 'ASC', 'tip' => __('The name of this Data Input Method.')),
-		'nosort'       => array('display' => __('Deletable'),          'align' => 'right', 'tip' => __('Data Inputs that are in use cannot be Deleted. In use is defined as being referenced either by a Data Source or a Data Template.')),
-		'data_sources' => array('display' => __('Data Sources Using'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The number of Data Sources that use this Data Input Method.')),
-		'templates'    => array('display' => __('Templates Using'),    'align' => 'right', 'sort' => 'DESC', 'tip' => __('The number of Data Templates that use this Data Input Method.')),
-		'type_id'      => array('display' => __('Data Input Method'),  'align' => 'right', 'sort' => 'ASC', 'tip' => __('The method used to gather information for this Data Input Method.')));
+		'id' => array(
+			'display' => __('ID'),
+			'align'   => 'right',
+			'sort'    => 'ASC',
+			'tip'     => __('The internal database ID for this Data Input Method.  Useful when performing automation or debugging.')
+		),
+		'nosort' => array(
+			'display' => __('Deletable'),
+			'align'   => 'right',
+			'tip'     => __('Data Inputs that are in use cannot be Deleted. In use is defined as being referenced either by a Data Source or a Data Template.')
+		),
+		'data_sources' => array(
+			'display' => __('Data Sources Using'),
+			'align'   => 'right',
+			'sort'    => 'DESC',
+			'tip'     => __('The number of Data Sources that use this Data Input Method.')
+		),
+		'templates' => array(
+			'display' => __('Templates Using'),
+			'align'   => 'right',
+			'sort'    => 'DESC',
+			'tip'     => __('The number of Data Templates that use this Data Input Method.')
+		),
+		'type_id' => array(
+			'display' => __('Data Input Method'),
+			'align'   => 'right',
+			'sort'    => 'ASC',
+			'tip'     => __('The method used to gather information for this Data Input Method.')
+		)
+	);
 
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
@@ -946,7 +971,8 @@ function data() {
 			}
 			form_alternate_row('line' . $data_input['id'], true, $disabled);
 			form_selectable_cell(filter_value($data_input['name'], get_request_var('filter'), 'data_input.php?action=edit&id=' . $data_input['id']), $data_input['id']);
-			form_selectable_cell($disabled ? __('No'):__('Yes'), $data_input['id'],'', 'right');
+			form_selectable_cell($data_input['id'], $data_input['id'], '', 'right');
+			form_selectable_cell($disabled ? __('No'):__('Yes'), $data_input['id'], '', 'right');
 			form_selectable_cell(number_format_i18n($data_input['data_sources'], '-1'), $data_input['id'],'', 'right');
 			form_selectable_cell(number_format_i18n($data_input['templates'], '-1'), $data_input['id'],'', 'right');
 			form_selectable_cell($input_types[$data_input['type_id']], $data_input['id'], '', 'right');
