@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -220,6 +220,13 @@ case 'tree':
 
 	top_graph_header();
 
+	?>
+	<script type='text/javascript'>
+	minTreeWidth = <?php print read_user_setting('min_tree_width');?>;
+	maxTreeWidth = <?php print read_user_setting('max_tree_width');?>;
+	</script>
+	<?php
+
 	bottom_footer();
 
 	break;
@@ -640,7 +647,7 @@ case 'list':
 												}
 											}
 											print '>';
-											print $gt['name'] . "</option>\n";
+											print html_escape($gt['name']) . "</option>\n";
 										}
 									}
 								}
@@ -777,7 +784,7 @@ case 'list':
 		$report_text .= '<tr><td>' . __('Report Name') . '</td>';
 		$report_text .= '<td><select id="report_id">';
 		foreach($reports as $report) {
-			$report_text .= '<option value="' . $report['id'] . '">' . $report['name'] . '</option>';
+			$report_text .= '<option value="' . $report['id'] . '">' . html_escape($report['name']) . '</option>';
 		}
 		$report_text .= '</select></td></tr>';
 
