@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,7 +22,7 @@
  +-------------------------------------------------------------------------+
 */
 
-print "\t\t\t</div>\n\t\t</div>\n\t</div>\n";
+print "\t\t\t</main>\n\t\t</div>\n\t</div>\n";
 if (!isset_request_var('pagecontent')) {
 	api_plugin_hook('page_bottom');
 	print "\t</body>\n</html>\n";
