@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -64,7 +64,7 @@ function upgrade_to_0_8_7c() {
 	db_install_execute("ALTER TABLE `poller_time` MODIFY COLUMN `pid` INT(11) UNSIGNED NOT NULL DEFAULT '0';");
 
 	/* Update deletion verification setting */
-	db_install_execute("UPDATE settings SET name = 'deletion_verification' WHERE name = 'remove_verification'");
+	db_install_swap_setting('remove_verification', 'deletion_verification');
 
 	/* Correct issue where rrd_next_step goes large in a positive way instead of the way it should go */
 	db_install_execute("ALTER TABLE `poller_item` MODIFY COLUMN `rrd_step` MEDIUMINT(8) NOT NULL DEFAULT 300");
