@@ -2648,6 +2648,12 @@ function reset_user_perms($user_id) {
 		SET reset_perms=FLOOR(RAND() * 4294967295) + 1
 		WHERE id = ?',
 		array($user_id));
+
+	if ($user_id == $_SESSION['sess_user_id']) {
+		kill_session_var('sess_user_realms');
+		kill_session_var('sess_user_config_array');
+		kill_session_var('sess_config_array');
+	}
 }
 
 /* is_user_perms_valid - checks to see if the admin has changed users permissions
